@@ -170,6 +170,10 @@ def muteLogs(app) :
     werkzeug_logger = logging.getLogger('werkzeug')
     werkzeug_logger.disabled = True
     app.logger.disabled = True
+    apscheduler_logger = logging.getLogger('apscheduler.scheduler')
+    apschedulerLoggerEnabled = app.globals.getApiSetting('api.scheduler.enable')
+    apscheduler_logger.disabled = True if ObjectHelper.isNone(apschedulerLoggerEnabled) else not apschedulerLoggerEnabled
+    apscheduler_logger.propagate = not apscheduler_logger.disabled
     WSGIRequestHandler.log = lambda self, type, message, *args: None ###- getattr(werkzeug_logger, type)('%s %s' % (self.address_string(), message % args))
 
 @Function
